@@ -251,7 +251,7 @@ def set_transition(room_name: str, transition_time: int, IP_ADDRESS: str) -> boo
     try:
         b = Bridge(IP_ADDRESS)
         lights = b.get_light_objects("name")
-        command = {"transitiontime" = transition_time, "on" = True, "bri" = 254}
+        command = {"transitiontime": transition_time, "on": True, "bri": 254}
         
         for light in lights[room_name]:
         	light.on = True
